icsemantic.catalog.criteria.translation.ATTranslationCriterion

Package platecom :: Package ontocatalog :: Package criteria :: Module translation :: Class ATTranslationCriterion |
[hide private]
[frames] | no frames]

# Class ATTranslationCriterion

source code

    Products.ATContentTypes.criteria.base.ATBaseCriterion --+
                                                            |
                                                           ATTranslationCriterion

A translation text criterion

Instance Methods | [hide private]
getLanguages(self) | source code
getCriteriaItems(self) | source code

Class Variables | [hide private]
| __implements__ = `ATBaseCriterion.__implements__+(IATTopicSearc`...``
| security = `ClassSecurityInfo()`
| schema = `ATBaseCriterionSchema+ Schema((StringField('value', r`...``
| meta_type = `'ATTranslationCriterion'`
| archetype_name = `'Friendly Translation Criterion'`
| shortDesc = `'Translation Criterion'`

Class Variable Details | [hide private]

  ### __implements__ Value:
      ATBaseCriterion.__implements__+(IATTopicSearchCriterion,)

  ### schema Value:
      ATBaseCriterionSchema+ Schema((StringField('value', required= 1, mode=
       "rw", write_permission= ChangeTopics, accessor= "Value", mutator= "se
      tValue", default= "", widget= StringWidget(label= _(u'label_translatio
      n_criterion_value', default= u'Value'), description= _(u'help_translat
      ion_criterion_value', default= u'A string value.'))), LinesField('lang
      uage', required= 1, mode= "rw", write_permission= ChangeTopics, access
      or= "Language", mutator= "setLanguage", default= [], vocabulary= "getL
      anguages", widget= MultiSelectionWidget(label= _(u'label_translation_c
      ...